function PLOT_ENTROPY_FIG(SeriesModelName, Label, TimeHorizonIndex)

%
%
%
%
% Definition of basic variables. It is assumed a major directory containing
% all results; further specific directories are addressed in the variable
% "SeriesModelName", which specify the model used to generate the series.
% "window" is assumed constant; in case of modifications, nested functions
% and linked functions must be checked.


directory = ['/Users/pietromurialdo/BigData/Results/', SeriesModelName, '/'];
window = [30,50,100,150,200:100:1500];

%
%
%
%
% Load the sampled series length used to normalize entropy curves.

tmp = load([directory, 'SampledSeriesLength.mat']);
pathsLength = tmp.SampledSeriesLength;
clear tmp

%
%
%
%
%
% Load info used to generate the artificial data. Since Directory and info
% must match, eventual mismatches are indications of mistakes.

tmp = load([directory, 'SeriesInformation.mat'])
info = tmp.SeriesInformation;
clear tmp

%
%
%
%
% Load entropy matrix according to the model specified and the index passed
% as input

tmp = load([directory, 'EntropyMtx-M', num2str(TimeHorizonIndex), '.mat'])
paths = tmp.entropyMatrix;
clear tmp

%
%
%
%
% First block of code plots entropy curves figures.
%
% Second block writes figure specification inside the plot according to
% string vector Info.
%
% Third block saves figure
%
%
% %%%%%%%%%%
% %%%%%%%%%%
%
%
%
% Plot entropy curves

indexFig = (1:length(window))';
for k = 1:length(window)
    figure(9000);
    hold on; %fissa la figura in uso in modo che tutte le modifiche future vengano aggiunte alla figura corrente.
    grid off; %toglie la griglia.
    box on; %chiude gli assi a inquadrettare la figura.
    
    plot(paths{indexFig(k)}(:,1), ...
        - log(paths{indexFig(k)}(:,2) ./ (0.75 * pathsLength)), ...
        '.-');
    
    fig = gca;
    fig.XScale = 'lin';
    fig.YScale = 'lin';
    fig.XLim = [1 150];
    fig.XTick = [50 100 150];
                fig.YLim = [4 12];
                fig.YTick = [4:2:12];
                fig.YTickLabels = [1:0.5:3];
%     fig.YLim = [4 13]; %%%
%     fig.YTick = [4:2:12];
%     fig.YTickLabels = [1:0.5:3];
    xlabel('\tau [s]', 'fontsize', 18)
    ylabel('S(\tau,n)', 'fontsize', 16) %Cosa significa '[a.u.]'?
    
    freccia = annotation('arrow');
    freccia.Position = [0.45 0.3 -0.27 0.55];
    freccia.LineWidth = 0.75;
    text(22,11,'n','fontsize', 16)
end

%
%
%
%
% Figure specifications

dim = [.7, .3, .1, .1];
for i = 1:length(info)
    string{i} = info{i};
end
string{i + 1} = ['M', num2str(TimeHorizonIndex)];
annotation('textbox', dim, 'String', string, 'FitBoxToText', 'on', 'fontsize', 14);

if ischar(Label)
    dim = [.5, .15, .3, .3];
    annotation('textbox', dim, 'String', Label, 'FitBoxToText', 'on', 'fontsize', 16);
end

%
%
%
%
% Save Figure


filename = [directory, SeriesModelName, 'EntropyCurvesM', num2str(TimeHorizonIndex)];
%hgsave(filename)
print('-djpeg',filename)

close

end
